-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
--
-- (C) COPYRIGHT IBM CORP. 2002. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: %W%
-- 
-- Revision: %I%
-- 
-- Date: %G% %U%
-- 
-- Description: This is the IBM Tivoli Monitoring for WebSphere file for inserting 
--              static data into the TEDW TWH_CDW database tables.
-- 
--  ==========================================================================

-- All data is initially inserted into a temporary table that has
-- the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.

-- create a temporary table for generic component types

declare global temporary table IZY_CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.IZY_CompTyp values ('IZY_HOST',NULL, 'IBM WebSphere Application Server host', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_ADMIN_SERVER', NULL, 'IBM WebSphere administration server', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_APPL_SERVER',NULL, 'IBM WebSphere application server', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_DATA_SOURCE', NULL , 'IBM WebSphere data source', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_CONNECT_POOL', NULL, 'IBM WebSphere connection pool', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_EJB', NULL, 'IBM WebSphere Enterprise JavaBean', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_JVM', NULL, 'IBM WebSphere Java Virtual Machine', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_SERVLET_SESS', NULL, 'IBM WebSphere servlet session', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_THREAD_POOL', NULL, 'IBM WebSphere thread pool', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_TRANSACT_MGR', NULL, 'IBM WebSphere transaction manager ', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_WEB_APPL', NULL, 'IBM WebSphere web application', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.IZY_CompTyp values ('IZY_SERVLET', NULL, 'IBM WebSphere servlet', current timestamp - current timezone, '9999-01-01-00.00.00.000000');


-- insert the component types into the generic schema 
-- if not exist already

insert into TWG.CompTyp (CompTyp_Cd, CompTyp_Parent_Cd, CompTyp_Nm, CompTyp_Strt_DtTm, CompTyp_End_DtTm) 
select 
 c.CompTyp_Cd,
 c.CompTyp_Parent_Cd,
 c.CompTyp_Nm,
 c.CompTyp_Strt_DtTm,
 c.CompTyp_End_DtTm   
from 
 session.IZY_CompTyp c
where not exists
( select 1 from
  TWG.Cur_CompTyp t
  where
  t.CompTyp_cd=c.CompTyp_cd)
  ;



-- create a temporary table for measurement source cd 

declare global temporary table IZY_MSrc (
       MSrc_Cd              CHAR(6) NOT NULL,
       MSrc_Parent_Cd       CHAR(6) NOT NULL,
       MSrc_Nm              VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;


insert into session.IZY_MSrc values ('IZY', 'AMX', 'IBM Tivoli Monitoring for Web Infrastructure, Version 5.1.0: WebSphere Application Server');

insert into TWG.MSrc(MSrc_Cd, MSrc_Parent_Cd, MSrc_Nm) 
select 
 m.MSrc_Cd,
 m.MSrc_Parent_Cd,
 m.MSrc_Nm
from 
 session.IZY_MSrc m
where not exists
( select 1 from
  TWG.MSrc t
  where
  t.MSrc_Cd=m.MSrc_Cd )
  ;                                

--
-- create a temporary table for ITM for WebSphere measurement types
--

declare global temporary table IZY_MsmtTyp (
       MUnit_Cd          CHAR(6) NOT NULL,
       MSrc_Cd		    CHAR(6) NOT NULL,
       MsmtTyp_Nm           VARCHAR(120) NOT NULL,
       MsmtTyp_Ds           VARCHAR(254)
) 
with replace on commit preserve rows not logged
;


insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_connection_pool_wait_time', 'Connection pool average wait time per cycle');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Average_connection_pool_percent_used', 'Average percent of the connection pool that is in use');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Connection_pool_faults', 'Number of connection pool faults (e.g. timeout) in connection pool');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_EJB_response_time', 'Average total method response time for the remote methods of the bean for the cycle');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'EJB_request_rate', 'Number of calls to the remote methods of the bean per minute');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Average_concurrent_EJB_requests', 'Average number of concurrently active beans (entity and stateful) in the cycle');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Percent_EJB_returns_discarded', 'Percent of the EJB returns discarded');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'B', 'IZY', 'Used_JVM_memory', 'Used memory in JVM Runtime');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'B', 'IZY', 'Total_JVM_memory', 'Total memory in JVM Runtime');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Active_threads_to_pool_size_ratio', 'Ratio of active threads to pool size');

insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_servlet_response_time', 'Recent servlet response time (average)');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Servlet_request_rate', 'Number of requests that a servlet processed per minute');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Concurrent_servlet_requests', 'Number of servlet requests that are being concurrently processed (load)');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Servlet_error_rate', 'Servlet errors per cycle');

insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Live_servlet_sessions', 'Number of concurrently live servlet sessions (load)');

insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'Sec', 'IZY', 'Transaction_response_time', 'Recent transaction response time');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Transaction_request_rate', 'Transaction requests per minute');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Transaction_exceptions', 'Transaction time outs to total transactions');

insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'WebSphere_server_state_up', 'Server state is up');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'WebSphere_server_state_down', 'Server state is down');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'WebSphere_server_state_initializing', 'Server state is initializing');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'WebSphere_server_state_unknown', 'Server state is unknown');



-- insert the ITM for WebSphere measurement types into the generic schema 
-- if not exist already

insert into TWG.MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) 
select 
 m.MUnit_Cd,
 m.MSrc_Cd,
 m.MsmtTyp_Nm,
 m.MsmtTyp_Ds
from 
 session.IZY_MsmtTyp m
where not exists
( select 1 from
  TWG.MsmtTyp t
  where
  t.MsmtTyp_Nm=m.MsmtTyp_Nm
)
  ;


-- create a temporary table for ITM for WebSphere measurement rules
declare global temporary table IZY_MsmtRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.IZY_MsmtRul
select 'IZY_CONNECT_POOL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_connection_pool_wait_time',
   'Average_connection_pool_percent_used',
   'Connection_pool_faults'
);


insert into session.IZY_MsmtRul
select 'IZY_EJB', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_EJB_response_time',
   'EJB_request_rate',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded'
);

insert into session.IZY_MsmtRul
select 'IZY_JVM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Used_JVM_memory',
   'Total_JVM_memory'
);

insert into session.IZY_MsmtRul
select 'IZY_THREAD_POOL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Active_threads_to_pool_size_ratio'
); 

insert into session.IZY_MsmtRul
select 'IZY_WEB_APPL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_servlet_response_time',
   'Servlet_request_rate',
   'Concurrent_servlet_requests',
   'Servlet_error_rate'
);                     

insert into session.IZY_MsmtRul
select 'IZY_SERVLET', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_servlet_response_time',
   'Servlet_request_rate',
   'Concurrent_servlet_requests',
   'Servlet_error_rate'
);


insert into session.IZY_MsmtRul
select 'IZY_SERVLET_SESS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Live_servlet_sessions'
);

insert into session.IZY_MsmtRul
select 'IZY_TRANSACT_MGR', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Transaction_response_time',
   'Transaction_request_rate',
   'Transaction_exceptions'
);

insert into session.IZY_MsmtRul
select 'IZY_APPL_SERVER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_EJB_response_time',
   'EJB_request_rate',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded',
   'Average_servlet_response_time',
   'Servlet_request_rate',
   'Concurrent_servlet_requests',
   'Servlet_error_rate',               
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown'
);   
               

insert into session.IZY_MsmtRul
select 'IZY_ADMIN_SERVER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown'
);   

-- insert the measurement rule into the generic schema 
-- if not exist already

insert into TWG.MsmtRul (CompTyp_Cd, MsmtTyp_ID) 
select 
 m.CompTyp_Cd,
 m.MsmtTyp_ID
from 
 session.IZY_MsmtRul m
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.CompTyp_Cd=m.CompTyp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;



-- create a temporary table for ITM for WebSphere attribute types
declare global temporary table IZY_AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.IZY_AttrTyp values ('IZY_WAS_VERSION', 'Version of IBM WebSphere Application Server');
insert into session.IZY_AttrTyp values ('IZY_OS_TYPE', 'Operating system');
insert into session.IZY_AttrTyp values ('IZY_POLICY_REGION', 'Tivoli policy region');

-- insert the ITM for WebSphere attribute types into the generic schema 
-- if not exist already

insert into TWG.AttrTyp (AttrTyp_Cd, AttrTyp_Nm) 
select 
 m.AttrTyp_Cd,
 m.AttrTyp_Nm
from 
 session.IZY_AttrTyp m
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=m.AttrTyp_Cd )
  ;

--
-- Insert measurement group type codes
--         
-- nothing to insert


-- create a temporary table for measurement group 
declare global temporary table IZY_MGrp (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MGrp_Parent_Cd       CHAR(6),
       MGrp_Nm              VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;  

insert into session.IZY_MGrp values ('IZY_ST','STATE',NULL,'IBM WebSphere Application Server states');

-- insert the measurement group into the generic schema 
-- if it does not exist already

insert into TWG.MGrp (MGrp_Cd, MGrpTyp_Cd, MGrp_Parent_Cd, MGrp_Nm)
select 
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MGrp_Parent_Cd,
 m.MGrp_Nm 
from 
 session.IZY_MGrp m
where not exists
( select 1 from
  TWG.MGrp t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd
) 
;

-- create a temporary table for measurement group member 

declare global temporary table IZY_MGrpMbr (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
       
)
with replace on commit preserve rows not logged
;


insert into session.IZY_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (              
   'Average_connection_pool_wait_time',
   'Average_connection_pool_percent_used',
   'Average_EJB_response_time',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded',
   'Used_JVM_memory',
   'Active_threads_to_pool_size_ratio',
   'Average_servlet_response_time',
   'Concurrent_servlet_requests',
   'Live_servlet_sessions',
   'Transaction_response_time',
   'Transaction_request_rate'
);

insert into session.IZY_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and
MsmtTyp_Nm in (
   'Average_connection_pool_wait_time',
   'Average_connection_pool_percent_used',
   'Average_EJB_response_time',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded',
   'Used_JVM_memory',
   'Active_threads_to_pool_size_ratio',
   'Average_servlet_response_time',
   'Concurrent_servlet_requests',
   'Live_servlet_sessions',
   'Transaction_response_time',
   'Transaction_request_rate'
);

insert into session.IZY_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (
   'Average_connection_pool_wait_time',
   'Average_connection_pool_percent_used',
   'Average_EJB_response_time',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded',
   'Used_JVM_memory',
   'Active_threads_to_pool_size_ratio',
   'Average_servlet_response_time',
   'Concurrent_servlet_requests',
   'Live_servlet_sessions',
   'Transaction_response_time',
   'Transaction_request_rate',  
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown'
);

insert into session.IZY_MGrpMbr
select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and
MsmtTyp_Nm in (
   'Connection_pool_faults',
   'EJB_request_rate',     
   'Total_JVM_memory',
   'Servlet_request_rate',
   'Servlet_error_rate',
   'Transaction_exceptions'
);

insert into session.IZY_MGrpMbr
select 'IZY_ST','STATE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown'
);


insert into TWG.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
select 
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MsmtTyp_ID
from 
 session.IZY_MGrpMbr m
where not exists
( select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;  

---------------------------------------
-- temporary table for  RelnTyp
---------------------------------------
-- nothing to insert

--------------------------------------------------
-- Temporary for TWG.RelnRul
----------------------------------------

declare global temporary TABLE IZY_RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;


insert into session.IZY_RelnRul values ('IP_HOST','IZY_ADMIN_SERVER','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IP_INTERFACE','IZY_ADMIN_SERVER','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_HOST','IZY_ADMIN_SERVER','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_ADMIN_SERVER','IZY_APPL_SERVER','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_DATA_SOURCE','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_DATA_SOURCE','IZY_CONNECT_POOL','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_EJB','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_JVM','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_SERVLET_SESS','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_THREAD_POOL','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_TRANSACT_MGR','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_APPL_SERVER','IZY_WEB_APPL','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into session.IZY_RelnRul values ('IZY_WEB_APPL','IZY_SERVLET','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');



insert into TWG.RelnRul (CompTyp_Source_Cd,CompTyp_Target_Cd, RelnTyp_Cd, RelnRul_Strt_DtTm, RelnRul_End_DtTm)
select
 m.CompTyp_Source_Cd,
 m.CompTyp_Target_Cd,
 m.RelnTyp_Cd,
 m.RelnRul_Strt_DtTm,
 m.RelnRul_End_DtTm
from
 session.IZY_RelnRul m
where
 not exists
( select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = m.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = m.CompTyp_Target_Cd and
  t.RelnTyp_Cd = m.RelnTyp_Cd 
  )
; 
--------------------------------------
-- temporary table for AttrRul 
---------------------------------------
declare global temporary table IZY_AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;   


insert into session.IZY_AttrRul values ('IZY_HOST','AMX_EID', current timestamp, '9999-01-01-00.00.00.000000','N');
insert into session.IZY_AttrRul values ('IZY_HOST','AMX_GMT_OFFSET', current timestamp, '9999-01-01-00.00.00.000000','N');
insert into session.IZY_AttrRul values ('IZY_ADMIN_SERVER','IZY_WAS_VERSION', current timestamp, '9999-01-01-00.00.00.000000','N');
insert into session.IZY_AttrRul values ('IZY_ADMIN_SERVER','IZY_OS_TYPE', current timestamp, '9999-01-01-00.00.00.000000','N');
insert into session.IZY_AttrRul values ('IZY_ADMIN_SERVER','IZY_POLICY_REGION', current timestamp, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul (CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, AttrRul_Dom_Ind)
select 
 t.CompTyp_Cd ,
 t.AttrTyp_Cd ,
 t.AttrRul_Strt_DtTm ,
 t.AttrRul_End_DtTm ,
 t.AttrRul_Dom_Ind 
from 
 session.IZY_AttrRul t
where not exists
( select 1 from
  TWG.AttrRul m
  where
  t.CompTyp_Cd = m.CompTyp_Cd and
  t.AttrTyp_Cd = m.AttrTyp_Cd
  )
; 
   

----------------------------------------------
-- Translation tables
----------------------------------------------
--------------------------------------------------
-- Need to link the ITM for WAS Resource to the compTyp_cd 
----------------------------------------------

declare global temporary table IZY_Resource_Transl (
Resource		varchar(128) not null,
CompTyp_Cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;

insert into session.IZY_Resource_Transl values ('WebSphereASAdminServer','IZY_ADMIN_SERVER');
insert into session.IZY_Resource_Transl values ('WebSphereASApplicationServer','IZY_APPL_SERVER');
insert into session.IZY_Resource_Transl values ('WebSphereASDataSource','IZY_DATA_SOURCE');
insert into session.IZY_Resource_Transl values ('WebSphereASConnectionPool','IZY_CONNECT_POOL');
insert into session.IZY_Resource_Transl values ('WebSphereASEJB','IZY_EJB');
insert into session.IZY_Resource_Transl values ('WebSphereASJVMRuntime','IZY_JVM');
insert into session.IZY_Resource_Transl values ('WebSphereASServletSession','IZY_SERVLET_SESS');
insert into session.IZY_Resource_Transl values ('WebSphereASTransaction','IZY_TRANSACT_MGR');
insert into session.IZY_Resource_Transl values ('WebSphereASThreadPool','IZY_THREAD_POOL');
insert into session.IZY_Resource_Transl values ('WebSphereASWebApplication','IZY_WEB_APPL');
insert into session.IZY_Resource_Transl values ('WebSphereASServlet','IZY_SERVLET');

insert into AMX.Resource_Transl(Resource, CompTyp_Cd) 
select 
t.Resource  ,
t.CompTyp_Cd  
from 
 session.IZY_Resource_Transl t
where not exists
( select 1 from
  AMX.Resource_Transl m
  where
  t.CompTyp_Cd = m.CompTyp_Cd 
  )
; 

--------------------------------------------------
-- Need to link the ITM Category to the AVA code 
----------------------------------------------

declare global temporary table IZY_Category_Transl (
Category		varchar(128) not null,
MSrc_Cd			char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.IZY_Category_Transl values ('WebSphereAS','IZY');


insert into AMX.Category_Transl (Category, MSrc_Cd)
select 
t.Category ,
t.MSrc_Cd  
from 
 session.IZY_Category_Transl t
where not exists
( select 1 from
  AMX.Category_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd 
  )
; 

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters 
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------

declare global temporary table IZY_CompTyp_Transl (
MSrc_Cd			char(3) not null,
ITM_Key_Property	varchar(1096) not null,
CompTyp_Cd		varchar(17) not null,
Comp_Format_Nm	varchar(254) not null
)
with replace on commit preserve rows not logged
;

insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASAdminServer.Name','IZY_ADMIN_SERVER','WebSphereASAdminServer.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASApplicationServer.Name','IZY_APPL_SERVER','WebSphereASApplicationServer.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASDataSource.Name','IZY_DATA_SOURCE','WebSphereASDataSource.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASConnectionPool.Name','IZY_CONNECT_POOL','WebSphereASConnectionPool.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASEJB.Name','IZY_EJB','WebSphereASEJB.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASJVMRuntime.Name','IZY_JVM','WebSphereASJVMRuntime.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASServletSession.Name','IZY_SERVLET_SESS','WebSphereASServletSession.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASThreadPool.Name','IZY_THREAD_POOL','WebSphereASThreadPool.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASTransaction.Name','IZY_TRANSACT_MGR','WebSphereASTransaction.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASWebApplication.Name','IZY_WEB_APPL','WebSphereASWebApplication.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASServlet.Name','IZY_SERVLET','WebSphereASServlet.Name');




insert into AMX.Comptyp_Transl (MSrc_Cd, ITM_Key_Property, CompTyp_Cd,Comp_Format_Nm)
select 
t.MSrc_Cd  ,
t.ITM_key_property ,
t.CompTyp_Cd  ,
t.Comp_Format_Nm  
from 
 session.IZY_Comptyp_Transl t
where not exists
( select 1 from
  AMX.Comptyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.CompTyp_Cd  = m.CompTyp_Cd 
  )
; 


--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters
----------------------------------------------
declare global temporary table IZY_AttrTyp_Transl (
MSrc_Cd			char(3) not null,
ITM_Attr_Property	varchar(254) not null,
AttrTyp_Cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;



insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASAdminServer.WasVersion','IZY_WAS_VERSION');
insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASAdminServer.OSType','IZY_OS_TYPE');
insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASAdminServer.PolicyRegion','IZY_POLICY_REGION');


insert into AMX.Attrtyp_Transl (MSrc_Cd, ITM_Attr_Property, AttrTyp_Cd)
select 
t.MSrc_Cd  ,
t.ITM_Attr_Property  ,
t.AttrTyp_Cd 
from 
 session.IZY_Attrtyp_Transl t
where not exists
( select 1 from
  AMX.Attrtyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.AttrTyp_Cd  = m.AttrTyp_Cd 
  )
; 
               

--------------------------------------------------------------------
--Insert data into control table for pruning data from Msmt table.
--A date duration is decimal(8,0) and has the format yyyymmdd.
--------------------------------------------------------------------

declare global temporary table prune_msmt_control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values (
  'IZY', 'H', 00000300
);
insert into session.Prune_Msmt_Control values (
  'IZY', 'D', 00000300
);
insert into session.Prune_Msmt_Control values (
  'IZY', 'W', 00010000
);
insert into session.Prune_Msmt_Control values (
  'IZY', 'M', 00010000
);

insert into TWG.Prune_Msmt_Control(MSrc_Cd,TmSum_Cd, PMsmtC_Age_In_Days)
select * from 
 session.Prune_Msmt_Control s
where not exists
( select 1 from
  TWG.Prune_Msmt_Control t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.TmSum_Cd = s.TmSum_Cd)
;


---------------------------------------
-- temporary table for Extract Control
---------------------------------------
 declare global temporary table Extract_Control (
        ExtCtl_Source   	varchar(120) not null,
 	ExtCtl_Target   	varchar(120) not null,
 	ExtCtl_From_RawSeq      char(10) for bit data,
 	ExtCtl_To_RawSeq        char(10) for bit data,
 	ExtCtl_From_IntSeq      bigint,
 	ExtCtl_To_IntSeq        bigint,
 	ExtCtl_From_DtTm     	timestamp not null,
 	ExtCtl_To_DtTm       	timestamp not null
	)
with replace on commit preserve rows not logged
;

-----------------------------------------------
-- From TWG.MSMT to the Mart Fact tables
-----------------------------------------------

insert into session.extract_control values (
    'TWG.MSMT' ,
    'IZY.STAGE_F_ADMIN_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'IZY.STAGE_F_APPL_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'IZY.STAGE_F_APCMP_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'IZY.STAGE_F_SBCMP_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------
-- From SHADOW Dimension tables in CDW to the Mart Dimension tables
-------------------------------------------------------------------

insert into session.extract_control values (
    'IZY.STAGE_D_WAS_METRIC' ,
    'IZY.D_WAS_METRIC' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- From TWG.COMP to the Mart Dimension tables
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP',
    'IZY.D_WAS_HOST' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.COMP',
    'IZY.D_WAS_ADMINSRV' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.COMP',
    'IZY.D_WAS_APPLSRV' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);



insert into session.extract_control values (
    'TWG.COMP',
    'IZY.D_WAS_APPLCMP' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);



insert into session.extract_control values (
    'TWG.COMP',
    'IZY.D_WAS_SUBCMP' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-- insert the static data for the extract table 
-- if not exist already

insert into TWG.Extract_control(ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
 m.ExtCtl_Source  ,
 m.ExtCtl_Target  ,
 m.ExtCtl_From_RawSeq  ,
 m.ExtCtl_To_RawSeq  ,
 m.ExtCtl_From_IntSeq  ,
 m.ExtCtl_To_IntSeq  ,
 m.ExtCtl_From_DtTm  ,
 m.ExtCtl_To_DtTm    
from 
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
; 
   
-----------------------------------------------
-- insert the dimension: WebSphere metric info
-- for the WebSphere DataMart
-----------------------------------------------



declare global temporary table temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;

-- select * from session.temp_min_exists;
-- select count(*) from session.temp_min_exists;


declare global temporary table temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;
-- select count(*) from session.temp_max_exists;


declare global temporary table temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'    AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'

;

-- select count(*) from session.temp_avg_exists;


declare global temporary table temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb, 
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'

;

-- select count(*) from session.temp_tot_exists;


-- Insert measurements with WebSphere specific measurement groups,
-- using Measurement Group table MGrp_Nm as the category (for met_Category) 

declare global temporary table temp_category (
 msmttyp_id	integer,
 category     varchar(120)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_category
select
 mb.msmttyp_id,
 mg.mgrp_nm as category
from
 TWG.MgrpMbr mb,
 TWG.Mgrp mg
where
 mb.mgrptyp_cd = 'STATE' and
 mb.mgrp_cd='IZY_ST' and
 mb.mgrp_cd = mg.mgrp_cd
;

-- select count(*) from session.temp_category;


drop table IZY.STAGE_D_WAS_METRIC;

create table IZY.STAGE_D_WAS_METRIC (
 insert_dttm		timestamp,
 Metric_ID            integer not null,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc          VARCHAR(254) NOT NULL,
 Met_Name          VARCHAR(120) NOT NULL,
 Met_Units         CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm				 VARCHAR(50) NOT NULL,
       PRIMARY KEY (Metric_ID)
);

insert  into IZY.STAGE_D_WAS_METRIC
select
 current timestamp as insert_dttm,
 mt.msmttyp_id as metric_id,
 value(cat.category,'not used') as Met_Category,
 mt.msmttyp_ds as met_desc,
 mt.msmttyp_nm as met_name,
 mt.munit_cd as met_units,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'IZY' as msrc_nm
from
 TWG.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.msmttyp mt5 left outer join session.temp_category cat
 on mt5.msmttyp_id=cat.msmttyp_id,
 TWG.MsmtRul mr
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mr.comptyp_cd in ('IZY_ADMIN_SERVER','IZY_APPL_SERVER','IZY_DATA_SOURCE','IZY_CONNECT_POOL',
                   'IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_TRANSACT_MGR',
                   'IZY_THREAD_POOL','IZY_WEB_APPL','IZY_SERVLET') and
 mt.MSrc_Cd = 'IZY' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 mt.msmttyp_id = mt5.msmttyp_id
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd, 
 min_exists, avg_exists, tot_exists, max_exists,cat.category
;


