-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
--
-- (C) COPYRIGHT IBM CORP. 2002. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: %W%
-- 
-- Revision: %I%
-- 
-- Date: %G% %U%
-- 
-- Description: IBM Tivoli Monitoring  for WebSphere file for moving data 
--              from the Central Data Warehouse tables in TWH_CDW to the  
--              metric dimension tables in the data mart (TWH_Mart).                             
-- ==========================================================================
---------------------------------
-- insert the metric dimension
------------------------------
-- get the high value for the window

update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(metric_id) from IZY.STAGE_D_WAS_METRIC)
where 
 extctl_source='IZY.STAGE_D_WAS_METRIC' and
 extctl_target='IZY.D_WAS_METRIC' and
 (select count(*) from IZY.STAGE_D_WAS_METRIC ) >0
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_MRT_METRIC;

-- Staging table for Data mart cross DB transfers 
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_MRT_METRIC (
 Metric_ID            INTEGER NOT NULL,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc				 VARCHAR(254) NOT NULL,
 Met_Name             VARCHAR(120) NOT NULL,
 Met_Units            CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm					 VARCHAR(120) NOT NULL,
       PRIMARY KEY (Metric_ID)
);


-- Insert new metric data from staging table into the data mart table
--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_MRT_METRIC
select 
 d.metric_id as metric_id, 
 d.met_category as met_category,
 d.met_desc as met_desc,
 d.met_name as met_name,
 d.met_units as met_units,
 d.min_exists as min_exists,
 d.max_exists as max_exists,
 d.avg_exists as avg_exists,
 d.total_exists as total_exists,
 d.msrc_nm as msrc_nm
from
 IZY.STAGE_D_WAS_METRIC d,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'IZY.STAGE_D_WAS_METRIC' and
 ec.extctl_target = 'IZY.D_WAS_METRIC' and
 d.metric_id > ec.extctl_from_intseq and
 d.metric_id <= ec.extctl_to_intseq 
;


-- copy WebSphere measurements from staging table into Mart metric table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_METRIC
select * from IZY.STAGE_D_MRT_METRIC s
where not exists
( select 1 from
  IZY.D_WAS_METRIC d
  where
  d.metric_id = s.metric_id
);                                
;                                

-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log 
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source  ,
 ec.extctl_target  ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq  ,
 ec.extctl_to_rawseq  ,
 ec.extctl_from_intseq  ,
 ec.extctl_to_intseq  ,
 ec.extctl_from_dttm  ,
 ec.extctl_to_dttm  
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'IZY.STAGE_D_WAS_METRIC' and
 ec.extctl_target = 'IZY.D_WAS_METRIC'
; 

-----------------------------------------------
--  insert the dimension: Hosts 
-----------------------------------------------

-- get the high value for the window
-- cr1.comp_source_id = host of IZY_ADMIN_SERVER
update TWG.Extract_Control set 
 extctl_to_intseq =  
   (select max(cr1.comp_source_id) 
        from twg.Cur_comp co1, 
             TWG.Cur_CompReln cr1
        where 
           co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
           co1.comp_id = cr1.comp_target_id and
           cr1.relntyp_cd='PCHILD'
    )
where 
 extctl_source='TWG.COMP' and
 extctl_target='IZY.D_WAS_HOST' and
 (select count(*) from twg.Cur_comp co1, TWG.Cur_CompReln cr1
                                where comptyp_cd = 'IZY_ADMIN_SERVER' and
                                      co1.comp_id = cr1.comp_target_id and
                                      cr1.relntyp_cd='PCHILD') >0 
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_HOST;

-- WebSphere Host dimension table   
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_HOST(
 host_id     		integer not null,
 host_name    		varchar(254) not null,
 cust_nm		varchar(120) not null,
 centr_nm  		varchar(120) not NULL,
      primary key (host_id)
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_HOST
select 
 cr1.comp_source_id as host_id,
 co2.comp_nm as host_name,
 cu1.cust_nm as cust_nm,
 ce1.centr_nm as centr_nm
from
 TWG.Cur_Comp co1,
 TWG.Cur_Comp co2,
 TWG.Cur_CompReln cr1,
 TWG.Cust cu1,
 TWG.Centr ce1,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_HOST' and
 cr1.comp_source_id > ec.extctl_from_intseq and
 cr1.comp_source_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
 co1.comp_id = cr1.comp_target_id and
 cr1.relntyp_cd='PCHILD' and 
 cr1.comp_source_id = co2.comp_id and
 co2.cust_id = cu1.cust_id and
 co2.centr_cd = ce1.centr_cd 
group by
 cr1.comp_source_id, co2.comp_nm, cu1.cust_nm,  ce1.centr_nm 
;


-- copy WebSphere host components from staging table into Mart host table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_HOST
select * from IZY.STAGE_D_HOST s
where not exists
( select 1 from
  IZY.D_WAS_HOST d
  where
  d.host_id=s.host_id)
;                                


-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_HOST'
; 

----------------------------------------------------
--  insert the dimension: WebSphere AdminServer node 
----------------------------------------------------

-- get the high value for the window

update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(ca.compattr_id) from twg.Cur_comp co1, twg.Cur_compattr ca
    where 
        co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
        co1.comp_id = ca.comp_id and
        ca.attrtyp_cd in ('IZY_WAS_VERSION', 'IZY_POLICY_REGION', 'IZY_OS_TYPE') )
where 
 extctl_source='TWG.COMP' and
 extctl_target='IZY.D_WAS_ADMINSRV' and
 (select count(*) from twg.Cur_comp co1, twg.Cur_compattr ca 
 where 
  co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
  co1.comp_id = ca.comp_id and
  ca.attrtyp_cd in ('IZY_WAS_VERSION', 'IZY_POLICY_REGION') ) >0 
;


-- Temporary staging table for WebSphere AdminServer components and attributes
--#IGNORE_ERROR
drop table IZY.STAGE_ADMIN_ATTR;

-- create temporary table in CDW 
create table IZY.STAGE_ADMIN_ATTR (
 comp_id    integer not null,
 comp_name  varchar(254) not null, 
 compattr_strt_dttm		timestamp not null,
 primary key (comp_id, compattr_strt_dttm )
);

-- WebSphere AdminServer dimension table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_ADMINSRV;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_ADMINSRV (
 AdminSrv_Comp_ID    integer not null,
 AdminSrv_Comp_Name  varchar(254) not null, 
 XQ_AdminSrv_dttm		timestamp not null,
 AdminSrv_OS_Type       	varchar(254) not null,
 AdminSrv_WAS_Ver    	varchar(254) not null,
 AdminSrv_PolicyReg     varchar(254) not null,
 primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm )
);


-- Get new WebSphere Administration server components or components whose attributes 
-- have changed which implies a new component in the dimension table
insert into IZY.STAGE_ADMIN_ATTR
select 
 co1.comp_id as comp_id,
 co1.comp_nm as comp_nm,               
 max(ca.compattr_strt_dttm) as compattr_strt_dttm
from  
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_ADMINSRV' and
 ca.compattr_id > ec.extctl_from_intseq and
 ca.compattr_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
 ca.comp_id=co1.comp_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION') 
group by
 co1.comp_id, co1.comp_nm
; 

--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_ADMINSRV
select 
 s.comp_id as ADMINSRV_COMP_ID,
 s.comp_name as ADMINSRV_COMP_NAME, 
 s.compattr_strt_dttm as XQ_AdminSrv_dttm,
 ca1.compattr_val as ADMINSRV_OS_TYPE,
 ca2.compattr_val as AdminSrv_WAS_VER,
 ca3.compattr_val as AdminSrv_PolicyReg 
from
 IZY.STAGE_ADMIN_ATTR s,
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompAttr ca1,  
 TWG.Cur_CompAttr ca2,  
 TWG.Cur_CompAttr ca3   
where
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
 s.comp_id=co1.comp_id and  
 ca1.comp_id=s.comp_id and  
 ca1.attrtyp_cd = 'IZY_OS_TYPE' and  
 ca2.comp_id=s.comp_id and  
 ca2.attrtyp_cd = 'IZY_WAS_VERSION' and
 ca3.comp_id=s.comp_id and  
 ca3.attrtyp_cd = 'IZY_POLICY_REGION' 
group by
 s.comp_id, s.comp_name, s.compattr_strt_dttm,
 ca1.compattr_val, ca2.compattr_val, ca3.compattr_val 
;

-- copy WebSphere administration server component from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_ADMINSRV
select * from IZY.STAGE_D_ADMINSRV s
where not exists
( select 1 from
  IZY.D_WAS_ADMINSRV d
  where
  d.AdminSrv_Comp_ID = s.AdminSrv_Comp_id and
  d.XQ_AdminSrv_dttm = s.XQ_AdminSrv_dttm
);                                

-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_ADMINSRV'
; 

-------------------------------------------------------
--  insert the dimension: WebSphere Application server
-------------------------------------------------------

-- get the high value for the window

update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(co1.comp_id) from twg.Cur_comp co1 
    where 
        co1.comptyp_cd = 'IZY_APPL_SERVER' )
where 
 extctl_source='TWG.COMP' and
 extctl_target='IZY.D_WAS_APPLSRV' and
 (select count(*) from twg.Cur_comp co1 where co1.comptyp_cd = 'IZY_APPL_SERVER' ) >0 
;


-- WebSphere Application Server dimension table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop  table IZY.STAGE_D_APPLSRV;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_APPLSRV (
 ApplSrv_Comp_ID    integer not null,
 ApplSrv_Comp_Name  varchar(254) not NULL,
 primary key (ApplSrv_Comp_ID)
);
                 

--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_APPLSRV
select 
 co1.comp_id as ApplSrv_comp_id,
 co1.comp_nm as ApplSrv_comp_name
from
 TWG.Cur_Comp co1,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLSRV' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'IZY_APPL_SERVER'
group by
 co1.comp_id, co1.comp_nm
;                  

-- copy WebSphere application server component from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_APPLSRV
select * from IZY.STAGE_D_APPLSRV s
where not exists
( select 1 from
  IZY.D_WAS_APPLSRV d
  where
  d.ApplSrv_Comp_ID = s.ApplSrv_Comp_ID
);                                


-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone),
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLSRV'
; 


-----------------------------------------------------------
--  insert the dimension: Application Server Components
-----------------------------------------------------------

-- get the high value for the window

update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(comp_id) from twg.Cur_comp
    where comptyp_cd in 
         ('IZY_DATA_SOURCE','IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_THREAD_POOL','IZY_TRANSACT_MGR','IZY_WEB_APPL')
                     )
where 
 extctl_source='TWG.COMP' and
 extctl_target='IZY.D_WAS_APPLCMP' and
 (select count(*) from twg.Cur_comp where comptyp_cd in
  ('IZY_DATA_SOURCE','IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_THREAD_POOL','IZY_TRANSACT_MGR','IZY_WEB_APPL')
 ) >0 
;


-- WebSphere Application Server SubComponents dimension table
-- ie. JVM, EJBs, Web Applications, Servlets, DataSources...
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_APPLCMP;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_APPLCMP(
 ApplCmp_Comp_ID     integer not null,
 ApplCmp_Comp_Name   varchar(254) not null, 
 ApplCmp_Comp_TypeCd	char(17) not null,
 primary key (ApplCmp_Comp_ID)
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_APPLCMP
select  
 co1.comp_id as ApplCmp_Comp_id,
 co1.comp_nm as ApplCmp_Name, 
 co1.comptyp_cd as ApplCmp_TypeCd
from  
 TWG.Cur_Comp co1,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLCMP' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd in ('IZY_DATA_SOURCE','IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_THREAD_POOL','IZY_TRANSACT_MGR','IZY_WEB_APPL')
group by
 co1.comp_id, co1.comptyp_cd, co1.comp_nm
;


-- copy WebSphere application server components from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_APPLCMP
select * from IZY.STAGE_D_APPLCMP s
where not exists
( select 1 from
  IZY.D_WAS_APPLCMP d
  where
  d.ApplCmp_Comp_ID = s.ApplCmp_Comp_ID
);                                


-- confirm that the insertion 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLCMP'
; 

------------------------------------------------------------------------
-- insert the dimension: Subcomponent (Connection Pools, servlets)
-------------------------------------------------------------------------

-- get the high value for the window

update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(comp_id) from twg.Cur_comp
    where comptyp_cd in ('IZY_SERVLET','IZY_CONNECT_POOL') )
where 
 extctl_source='TWG.COMP' and
 extctl_target='IZY.D_WAS_SUBCMP' and
 (select count(*) from twg.Cur_comp where comptyp_cd in ('IZY_SERVLET','IZY_CONNECT_POOL')) >0 
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_SUBCMP;

-- WebSphere SubComponent dimension table
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_SUBCMP(
 SubCmp_Comp_ID     integer not null,
 SubCmp_Name   varchar(254) not null, 
 SubCmp_TypeCd	char(17) not null,
 primary key (SubCmp_Comp_ID)
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_SUBCMP
select  
 co1.comp_id as SubCmp_Comp_Id,
 co1.comp_nm as SubCmp_Name, 
 co1.comptyp_cd as SubCmp_TypeCd
from  
 TWG.Cur_Comp co1,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_SUBCMP' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd in ('IZY_SERVLET','IZY_CONNECT_POOL')
group by
 co1.comp_id, co1.comptyp_cd, co1.comp_nm
;


-- copy WebSphere application server subcomponent from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_SUBCMP
select * from IZY.STAGE_D_SUBCMP s
where not exists
( select 1 from
  IZY.D_WAS_SUBCMP d
  where
  d.SubCmp_Comp_ID = s.SubCmp_Comp_ID
);                                


-- confirm that the insertion 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_SUBCMP'
; 
