-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
--
-- (C) COPYRIGHT IBM CORP. 2002. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: %W%
-- 
-- Revision: %I%
-- 
-- Date: %G% %U%
-- 
-- Description: IBM Tivoli Monitoring  for WebSphere file for moving data 
--              from the tables in the Central Data Warehouse (TWH_CDW) 
--              to the fact dimension tables in the Data mart (TWH_Mart) via
--              staging tables in the data mart.  
--  
-- ==========================================================================
--
---------------------------
-- IZY_m05_s020_fact step
---------------------------
-- 
------------------------------------------------------------------------
--  Prune data from hourly, daily, weekly, monthly fact tables
------  according to the settings in the izy.Prune_Mart_Control table            
------  Log the pruning in the izy.prune_mart_log table
------  Remove any entries from the log where no pruning took place.                 
------------------------------------------------------------------------             

--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_ADMINSRV_HOUR
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_HOUR'),
     
     ( 
      select count(*) FROM IZY.F_ADMINSRV_HOUR f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_HOUR')
     )      
  )
           
; 

-- prune the hourly fact table IZY.F_ADMINSRV_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_HOUR f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_ADMINSRV_DAY
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_DAY'),
     
     ( 
      select count(*) FROM IZY.F_ADMINSRV_DAY f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_DAY')
     )      
  )
           
; 

-- prune the daily fact table IZY.F_ADMINSRV_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_DAY f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_ADMINSRV_WEEK
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_WEEK'),
     
     ( 
      select count(*) FROM IZY.F_ADMINSRV_WEEK f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_WEEK')
     )      
  )
           
; 

-- prune the weekly fact table IZY.F_ADMINSRV_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_WEEK f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_ADMINSRV_MONTH
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_MONTH'),
     
     ( 
      select count(*) FROM IZY.F_ADMINSRV_MONTH f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_MONTH')
     )      
  )
           
; 

-- prune the monthly fact table IZY.F_ADMINSRV_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_MONTH f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_APPLSRV_HOUR
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_HOUR'),
     
     ( 
      select count(*) FROM IZY.F_APPLSRV_HOUR f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_HOUR')
     )      
  )
           
; 

-- prune the hourly fact table IZY.F_APPLSRV_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_HOUR f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_APPLSRV_DAY
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_DAY'),
     
     ( 
      select count(*) FROM IZY.F_APPLSRV_DAY f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_DAY')
     )      
  )
           
; 

-- prune the daily fact table IZY.F_APPLSRV_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_DAY f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_APPLSRV_WEEK
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_WEEK'),
     
     ( 
      select count(*) FROM IZY.F_APPLSRV_WEEK f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_WEEK')
     )      
  )
           
; 

-- prune the weekly fact table IZY.F_APPLSRV_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_WEEK f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_APPLSRV_MONTH
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_MONTH'),
     
     ( 
      select count(*) FROM IZY.F_APPLSRV_MONTH f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_MONTH')
     )      
  )
           
; 

-- prune the monthly fact table IZY.F_APPLSRV_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_MONTH f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_APPLCMP_HOUR
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_HOUR'),
     
     ( 
      select count(*) FROM IZY.F_APPLCMP_HOUR f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_HOUR')
     )      
  )
           
; 

-- prune the hourly fact table IZY.F_APPLCMP_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_HOUR f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_APPLCMP_DAY
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_DAY'),
     
     ( 
      select count(*) FROM IZY.F_APPLCMP_DAY f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_DAY')
     )      
  )
           
; 

-- prune the daily fact table IZY.F_APPLCMP_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_DAY f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_APPLCMP_WEEK
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_WEEK'),
     
     ( 
      select count(*) FROM IZY.F_APPLCMP_WEEK f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_WEEK')
     )      
  )
           
; 

-- prune the weekly fact table IZY.F_APPLCMP_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_WEEK f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_WEEK')
;

--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_APPLCMP_MONTH
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_MONTH'),
     
     ( 
      select count(*) FROM IZY.F_APPLCMP_MONTH f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_MONTH')
     )      
  )
           
; 

-- prune the monthly fact table IZY.F_APPLCMP_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_MONTH f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_SUBCMP_HOUR
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_HOUR'),
     
     ( 
      select count(*) FROM IZY.F_SUBCMP_HOUR f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_HOUR')
     )      
  )
           
; 

-- prune the hourly fact table IZY.F_SUBCMP_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_HOUR f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_hour)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_SUBCMP_DAY
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_DAY'),
     
     ( 
      select count(*) FROM IZY.F_SUBCMP_DAY f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_DAY')
     )      
  )
           
; 

-- prune the daily fact table IZY.F_SUBCMP_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_DAY f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_SUBCMP_WEEK
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_WEEK'),
     
     ( 
      select count(*) FROM IZY.F_SUBCMP_WEEK f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_WEEK')
     )      
  )
           
; 

-- prune the weekly fact table IZY.F_SUBCMP_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_WEEK f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_SUBCMP_MONTH
--------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_MONTH'),
     
     ( 
      select count(*) FROM IZY.F_SUBCMP_MONTH f  WHERE
      (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
        (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_MONTH')
     )      
  )
           
; 

-- prune the monthly fact table IZY.F_SUBCMP_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_MONTH f
WHERE
   (DATE(CURRENT timestamp - CURRENT timezone) - DATE(f.meas_date)) > 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_MONTH')
;



-- delete entries in prune log where nothing was pruned
--#EXECUTE_AT_TARGET
DELETE FROM IZY.PRUNE_MART_LOG 
  WHERE NUMBER_PRUNED = 0
;

--------------------------------------------------------------------------------
-- insert the facts for WebSphere AdminServer (IZY_ADMIN_SERVER) component
--------------------------------------------------------------------------------
-- get the high value for the window

update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(msmt_id) from twg.msmt)
where 
 extctl_source='TWG.MSMT' and
 extctl_target='IZY.STAGE_F_ADMIN_HOUR' AND
 (select count(*) from twg.msmt ) >0  
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_ADMIN_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against AdminServer 
create table IZY.STAGE_F_ADMIN_HOUR (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_ADMIN_HOUR
select 
 m.comp_id as AdminSrv_Comp_ID, 
 max(ca.compattr_strt_dttm) as XQ_AdminSrv_dttm,
 cr1.comp_source_id as host_id,
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 avg(m.msmt_min_val) as min_value, 
 avg(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value,
 avg(m.msmt_tot_val) as total_value,
 avg(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 TWG.Cur_Comp co1,
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompAttr ca,  
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_ADMIN_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.comp_id=m.comp_id and            
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and         
 ca.comp_id=co1.comp_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD'
group by
 m.comp_id, cr1.comp_source_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_ADMINSRV_HOUR
select * from IZY.STAGE_F_ADMIN_HOUR
;

-- confirm that the insertion of 
-- the facts for WAS AdminServer has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone),
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_ADMIN_HOUR'
; 

------------------------------------------------------------------------------------
-- insert the facts for WebSphere Application Server (IZY_APPL_SERVER) component
------------------------------------------------------------------------------------
-- get the high value for the window


update TWG.Extract_Control set 
 extctl_to_intseq =  ( select max(msmt_id) from twg.msmt)
where 
 extctl_source='TWG.MSMT' and
 extctl_target='IZY.STAGE_F_APPL_HOUR' and
 (select count(*) from twg.msmt ) >0  
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_APPL_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against Application Server
create table IZY.STAGE_F_APPL_HOUR (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_APPL_HOUR
select 
 m.comp_id as ApplSrv_Comp_ID, 
 cr1.comp_source_id as AdminSrv_Comp_ID,
 max(ca.compattr_strt_dttm) as XQ_AdminSrv_dttm,
 cr2.comp_source_id as host_id,
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 avg(m.msmt_min_val) as min_value, 
 avg(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value,
 avg(m.msmt_tot_val) as total_value,
 avg(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompReln cr2,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APPL_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.comp_id=m.comp_id and
 co1.comptyp_cd = 'IZY_APPL_SERVER' and
 co1.comp_id = cr1.comp_target_id and
 cr1.relntyp_cd='PCHILD'and 
-- cr1.comp_source_id = adminSrv
 ca.comp_id=cr1.comp_source_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION') and
 cr1.comp_source_id = cr2.comp_target_id and 
 cr2.relntyp_cd='PCHILD'
group by
 m.comp_id, cr1.comp_source_id,cr2.comp_source_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;

--#EXECUTE_AT_TARGET
insert into IZY.F_APPLSRV_HOUR
select * from IZY.STAGE_F_APPL_HOUR
;

-- confirm that the insertion of 
-- the facts for WAS Application Server has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APPL_HOUR'
;                                                 


------------------------------------------------------------------------------------
-- insert the facts for the Subcomponents of the Application Server:
--       IZY_DATA_SOURCE,IZY_EJB, IZY_SERVLET_SESS, IZY_THREAD_POOL,IZY_TRANSACT_MGR, IZY_WEB_APPL
------------------------------------------------------------------------------------

-- get the high value for the window

update TWG.Extract_Control set 
extctl_to_intseq =  ( select max(msmt_id) from twg.msmt)
where 
 extctl_source='TWG.MSMT' and
 extctl_target='IZY.STAGE_F_APCMP_HOUR' and
 (select count(*) from twg.msmt ) >0  
;


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_APCMP_HOUR;

--#EXECUTE_AT_TARGET
-- Staging measurement hour fact table for all metrics against Application Server components
create table IZY.STAGE_F_APCMP_HOUR (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_APCMP_HOUR
select 
 m.comp_id as ApplCmp_Comp_ID, 
 cr1.comp_source_id as ApplSrv_Comp_ID,
 cr2.comp_source_id as AdminSrv_Comp_ID,
 max(ca.compattr_strt_dttm) as XQ_AdminSrv_dttm,
 cr3.comp_source_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 avg(m.msmt_min_val) as min_value, 
 avg(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 avg(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompReln cr2,
 TWG.Cur_CompReln cr3,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APCMP_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.comp_id=m.comp_id and
 co1.comptyp_cd in ('IZY_DATA_SOURCE',
                   'IZY_EJB',
                   'IZY_JVM',
                   'IZY_SERVLET_SESS',
                   'IZY_THREAD_POOL',
                   'IZY_TRANSACT_MGR',
                   'IZY_WEB_APPL') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' and
-- cr1  comp_source_id = appl server
 cr2.comp_target_id = cr1.comp_source_id and
 cr2.relntyp_cd='PCHILD' and
-- cr2  comp_source_id = adminserver
 ca.comp_id=cr2.comp_source_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION') and
-- cr3 = host machine
 cr3.comp_target_id = cr2.comp_source_id and
 cr3.relntyp_cd='PCHILD' 
group by
 m.comp_id, cr1.comp_source_id, cr2.comp_source_id, cr3.comp_source_id,
 m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_APPLCMP_HOUR
select * from IZY.STAGE_F_APCMP_HOUR
;


-- confirm that the insertion of the facts for the Subcomponents of the Application Server:
-- IZY_DATA_SOURCE,IZY_EJB, IZY_SERVLET_SESS, IZY_THREAD_POOL,IZY_TRANSACT_MGR, IZY_WEB_APPL
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APCMP_HOUR'
;



------------------------------------------------------------------------------------
-- insert the facts for the Subcomponents items of Data Sources and Web Applications:
------------------------------------------------------------------------------------

-- get the high value for the window

update TWG.Extract_Control set 
extctl_to_intseq =  ( select max(msmt_id) from twg.msmt)
where 
 extctl_source='TWG.MSMT' and
 extctl_target='IZY.STAGE_F_SBCMP_HOUR' and
 (select count(*) from twg.msmt ) >0  
;


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBCMP_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBCMP_HOUR (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select 
 m.comp_id as SubComp_Comp_ID, 
 cr1.comp_source_id as ApplCmp_Comp_ID, 
 cr2.comp_source_id as ApplSrv_Comp_ID,
 cr3.comp_source_id as AdminSrv_Comp_ID,
 max(ca.compattr_strt_dttm) as XQ_AdminSrv_dttm,
 cr4.comp_source_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 avg(m.msmt_min_val) as min_value, 
 avg(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 avg(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompReln cr2,
 TWG.Cur_CompReln cr3,
 TWG.Cur_CompReln cr4,                                         
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.comp_id=m.comp_id and
 co1.comptyp_cd in ('IZY_CONNECT_POOL','IZY_SERVLET') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' and
-- cr1.comp_source_id = Data Source or Web Appl
 cr2.comp_target_id = cr1.comp_source_id and
 cr2.relntyp_cd='PCHILD' and
-- cr2.comp_source_id = Appl server 
 cr3.comp_target_id = cr2.comp_source_id and
 cr3.relntyp_cd='PCHILD' and
-- cr3.comp_source_id = adminserver
 ca.comp_id=cr3.comp_source_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION') and
-- adminSrv = target, souce = host machine
 cr4.comp_target_id = cr3.comp_source_id and
 cr4.relntyp_cd='PCHILD'
group by
 m.comp_id, cr1.comp_source_id, cr2.comp_source_id, cr3.comp_source_id, cr4.comp_source_id,
 m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBCMP_HOUR
;


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR'
;

