-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
--
-- (C) COPYRIGHT IBM CORP. 2002. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: %W%
-- 
-- Revision: %I%
-- 
-- Date: %G% %U%
-- 
-- Description: This is the IBM Tivoli Monitoring for WebSphere file for creating
--              data mart tables in the TEDW TWH_Mart DB.
-- 
-- ==========================================================================
--
-- Tables created by IBM Tivoli Manager for WebSphere
-- Tables used in the data mart database
-- The owner of these tables is IZY
-- IZY is the AVA unique code for IBM Tivoli Manager for WebSphere

  
-----------------------------------------------
--- metric dimension
-----------------------------------------------

-- metric dimension table for all components.
-- This is a static table populated by sql scripts vs DWC

create table IZY.D_WAS_METRIC (
 Metric_ID            INTEGER NOT NULL,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc				 VARCHAR(254) NOT NULL,
 Met_Name             VARCHAR(120) NOT NULL,
 Met_Units            CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm					 VARCHAR(120) NOT NULL,
       PRIMARY KEY (Metric_ID)
);

-- Staging table for Data mart cross DB transfers 

create table IZY.STAGE_D_MRT_METRIC (
 Metric_ID            INTEGER NOT NULL,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc				 VARCHAR(254) NOT NULL,
 Met_Name             VARCHAR(120) NOT NULL,
 Met_Units            CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm					 VARCHAR(120) NOT NULL,
       PRIMARY KEY (Metric_ID)
);

--
------------------------------------------------
-- Component dimension tables 
------------------------------------------------
                                                                       
-- WebSphere Host dimension table

create table IZY.D_WAS_HOST(
 host_id     		integer not null,
 host_name    		varchar(254) not null,
 cust_nm		varchar(120) not null,
 centr_nm  		varchar(120) not NULL,
-- time_zone_name		varchar(120) not null,
      primary key (host_id)
);

-- WebSphere AdminServer dimension table

create table IZY.D_WAS_ADMINSRV(
 AdminSrv_Comp_ID    integer not null,
 AdminSrv_Comp_Name  varchar(254) not null, 
 XQ_AdminSrv_dttm		timestamp not null,
 AdminSrv_OS_Type       	varchar(254) not null,
 AdminSrv_WAS_Ver       	varchar(254) not null,
 AdminSrv_PolicyReg    varchar(254) not null,
 primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm )
);


-- WebSphere Application Server dimension table

create table IZY.D_WAS_APPLSRV(
 ApplSrv_Comp_ID    integer not null,
 ApplSrv_Comp_Name  varchar(254) not NULL,
 primary key (ApplSrv_Comp_ID)
);
                 

-- WebSphere Application Server SubComponents dimension table
-- ie. JVM, EJBs, Web Applications, Servlets, DataSources...

create table IZY.D_WAS_APPLCMP(
 ApplCmp_Comp_Id     integer not null,
 ApplCmp_Name     varchar(254) not null, 
 ApplCmp_TypeCd	char(17) not null,
 primary key (ApplCmp_Comp_ID)
);

-- WebSphere SubComponent Items dimension table

create table IZY.D_WAS_SUBCMP(
 SubCmp_Comp_Id  integer not null,
 SubCmp_Name   varchar(254) not null, 
 SubCmp_TypeCd	char(17) not null,
 primary key (SubCmp_Comp_Id)
);


------------------------------------------------
-- Staging tables for component dimension 
------------------------------------------------
                                                                       
                                                                       
-- WebSphere Host dimension table

create table IZY.STAGE_D_HOST(
 host_id     		integer not null,
 host_name    		varchar(254) not null,
 cust_nm		varchar(120) not null,
 centr_nm  		varchar(120) not NULL,
-- time_zone_name		varchar(120) not null,
      primary key (host_id)
);

-- WebSphere AdminServer dimension table

create table IZY.STAGE_D_ADMINSRV (
 AdminSrv_Comp_ID    integer not null,
 AdminSrv_Comp_Name  varchar(254) not null, 
 XQ_AdminSrv_dttm		timestamp not null,
 AdminSrv_OS_Type       	varchar(254) not null,
 AdminSrv_WAS_Ver    	varchar(254) not null,
 AdminSrv_PolicyReg     varchar(254) not null,
 primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm )
);


-- WebSphere Application Server dimension table

create table IZY.STAGE_D_APPLSRV (
 ApplSrv_Comp_ID    integer not null,
 ApplSrv_Comp_Name  varchar(254) not NULL,
 primary key (ApplSrv_Comp_ID)
);
                 

-- WebSphere Application Server SubComponents dimension table
-- ie. JVM, EJBs, Web Applications, Servlets, DataSources...

create table IZY.STAGE_D_APPLCMP(
 ApplCmp_Comp_ID     integer not null,
 ApplCmp_Comp_Name   varchar(254) not null, 
 ApplCmp_Comp_TypeCd	char(17) not null,
 primary key (ApplCmp_Comp_ID)
);

-- WebSphere SubComponent dimension table

create table IZY.STAGE_D_SUBCMP(
 SubCmp_Comp_ID     integer not null,
 SubCmp_Name   varchar(254) not null, 
 SubCmp_TypeCd	char(17) not null,
 primary key (SubCmp_Comp_ID)
);

--------------------------------------------------------------------
--
--      fact tables
---
-------------------------------------------------------------------

--------------
-- hour level
--------------

-- measurement hour fact table for all metrics against AdminServer
 
create table IZY.F_ADMINSRV_HOUR (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.F_ADMINSRV_HOUR
       ADD CONSTRAINT IZY_FH12
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_ADMINSRV_HOUR
       ADD CONSTRAINT IZY_FH11
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;


ALTER TABLE IZY.F_ADMINSRV_HOUR
       ADD CONSTRAINT IZY_FH10
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_ADMSRV_HOUR_idx1 on IZY.F_ADMINSRV_HOUR(AdminSrv_Comp_ID);
create index IZY.F_ADMSRV_HOUR_idx2 on IZY.F_ADMINSRV_HOUR(XQ_AdminSrv_dttm);
create index IZY.F_ADMSRV_HOUR_idx3 on IZY.F_ADMINSRV_HOUR(host_id);
create index IZY.F_ADMSRV_HOUR_idx4 on IZY.F_ADMINSRV_HOUR(metric_id);
create index IZY.F_ADMSRV_HOUR_idx5 on IZY.F_ADMINSRV_HOUR(meas_hour);


-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV_HOUR (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.F_APPLSRV_HOUR
       ADD CONSTRAINT IZY_FH23
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV_HOUR
       ADD CONSTRAINT IZY_FH22
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLSRV_HOUR
       ADD CONSTRAINT IZY_FH21
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLSRV_HOUR
       ADD CONSTRAINT IZY_FH20
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APPSRV_HOUR_idx1 on IZY.F_APPLSRV_HOUR(ApplSrv_Comp_ID);
create index IZY.F_APPSRV_HOUR_idx2 on IZY.F_APPLSRV_HOUR(AdminSrv_Comp_ID);
create index IZY.F_APPSRV_HOUR_idx3 on IZY.F_APPLSRV_HOUR(XQ_AdminSrv_dttm);
create index IZY.F_APPSRV_HOUR_idx4 on IZY.F_APPLSRV_HOUR(host_id);
create index IZY.F_APPSRV_HOUR_idx5 on IZY.F_APPLSRV_HOUR(metric_id);
create index IZY.F_APPSRV_HOUR_idx6 on IZY.F_APPLSRV_HOUR(meas_hour);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP_HOUR (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.F_APPLCMP_HOUR
       ADD CONSTRAINT IZY_FH34
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP_HOUR
       ADD CONSTRAINT IZY_FH33
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP_HOUR
       ADD CONSTRAINT IZY_FH32
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLCMP_HOUR
       ADD CONSTRAINT IZY_FH31
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLCMP_HOUR
       ADD CONSTRAINT IZY_FH30
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APPCMP_HOUR_idx1 on IZY.F_APPLCMP_HOUR(ApplCmp_Comp_ID);
create index IZY.F_APPCMP_HOUR_idx2 on IZY.F_APPLCMP_HOUR(ApplSrv_Comp_ID);
create index IZY.F_APPCMP_HOUR_idx3 on IZY.F_APPLCMP_HOUR(AdminSrv_Comp_ID);
create index IZY.F_APPCMP_HOUR_idx4 on IZY.F_APPLCMP_HOUR(XQ_AdminSrv_dttm);
create index IZY.F_APPCMP_HOUR_idx5 on IZY.F_APPLCMP_HOUR(host_id);
create index IZY.F_APPCMP_HOUR_idx6 on IZY.F_APPLCMP_HOUR(metric_id);
create index IZY.F_APPCMP_HOUR_idx7 on IZY.F_APPLCMP_HOUR(meas_hour);

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.F_SUBCMP_HOUR (
  SubCmp_Comp_ID    integer not null,
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);                

ALTER TABLE IZY.F_SUBCMP_HOUR
       ADD CONSTRAINT IZY_FH45
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP_HOUR
       ADD CONSTRAINT IZY_FH44
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP_HOUR
       ADD CONSTRAINT IZY_FH43
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP_HOUR
       ADD CONSTRAINT IZY_FH42
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_SUBCMP_HOUR
       ADD CONSTRAINT IZY_FH41
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_SUBCMP_HOUR
       ADD CONSTRAINT IZY_FH40
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SUBCMP_HOUR_idx1 on IZY.F_SUBCMP_HOUR(SubCmp_Comp_ID);
create index IZY.F_SUBCMP_HOUR_idx2 on IZY.F_SUBCMP_HOUR(ApplCmp_Comp_ID);
create index IZY.F_SUBCMP_HOUR_idx3 on IZY.F_SUBCMP_HOUR(ApplSrv_Comp_ID);
create index IZY.F_SUBCMP_HOUR_idx4 on IZY.F_SUBCMP_HOUR(AdminSrv_Comp_ID);
create index IZY.F_SUBCMP_HOUR_idx5 on IZY.F_SUBCMP_HOUR(XQ_AdminSrv_dttm);
create index IZY.F_SUBCMP_HOUR_idx6 on IZY.F_SUBCMP_HOUR(host_id);
create index IZY.F_SUBCMP_HOUR_idx7 on IZY.F_SUBCMP_HOUR(metric_id);
create index IZY.F_SUBCMP_HOUR_idx8 on IZY.F_SUBCMP_HOUR(meas_hour);

--------------------------------------------------------------------
--
--      Staging tables for fact tables
---
-------------------------------------------------------------------

-- measurement hour fact table for all metrics against AdminServer 
create table IZY.STAGE_F_ADMIN_HOUR (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_ADMIN_HOUR
       ADD CONSTRAINT IZY_SFH12
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.STAGE_F_ADMIN_HOUR
       ADD CONSTRAINT IZY_SFH11
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.STAGE_F_ADMIN_HOUR
       ADD CONSTRAINT IZY_SFH10
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;


-- measurement hour fact table for all metrics against Application Server
create table IZY.STAGE_F_APPL_HOUR (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_APPL_HOUR
       ADD CONSTRAINT IZY_SFH23
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.STAGE_F_APPL_HOUR
       ADD CONSTRAINT IZY_SFH22
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.STAGE_F_APPL_HOUR
       ADD CONSTRAINT IZY_SFH21
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.STAGE_F_APPL_HOUR
       ADD CONSTRAINT IZY_SFH20
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;



-- measurement hour fact table for all metrics against Application Server components
create table IZY.STAGE_F_APCMP_HOUR (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_APCMP_HOUR
       ADD CONSTRAINT IZY_SFH34
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.STAGE_F_APCMP_HOUR
       ADD CONSTRAINT IZY_SFH33
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.STAGE_F_APCMP_HOUR
       ADD CONSTRAINT IZY_SFH32
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.STAGE_F_APCMP_HOUR
       ADD CONSTRAINT IZY_SFH31
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.STAGE_F_APCMP_HOUR
       ADD CONSTRAINT IZY_SFH30
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;


-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBCMP_HOUR (
  SubCmp_Comp_ID    integer not null,
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_SBCMP_HOUR
       ADD CONSTRAINT IZY_SFH45
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.STAGE_F_SBCMP_HOUR
       ADD CONSTRAINT IZY_SFH44
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.STAGE_F_SBCMP_HOUR
       ADD CONSTRAINT IZY_SFH43
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.STAGE_F_SBCMP_HOUR
       ADD CONSTRAINT IZY_SFH42
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.STAGE_F_SBCMP_HOUR
       ADD CONSTRAINT IZY_SFH41
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.STAGE_F_SBCMP_HOUR
       ADD CONSTRAINT IZY_SFH40
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;



--------------
-- day level
--------------

-- FACT DAY table
-- The day, week, and month tables are populated by the aggregation UDP

create table IZY.F_ADMINSRV_DAY (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
   total_value double,
	sample_count integer,
	primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);      


ALTER TABLE IZY.F_ADMINSRV_DAY
       ADD CONSTRAINT IZY_FD12
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_ADMINSRV_DAY
       ADD CONSTRAINT IZY_FD11
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;
                                                         
ALTER TABLE IZY.F_ADMINSRV_DAY
       ADD CONSTRAINT IZY_FD10
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_ADMSRV_DAY_idx1 on IZY.F_ADMINSRV_DAY(AdminSrv_Comp_ID);
create index IZY.F_ADMSRV_DAY_idx2 on IZY.F_ADMINSRV_DAY(XQ_AdminSrv_dttm);
create index IZY.F_ADMSRV_DAY_idx3 on IZY.F_ADMINSRV_DAY(host_id);
create index IZY.F_ADMSRV_DAY_idx4 on IZY.F_ADMINSRV_DAY(metric_id);
create index IZY.F_ADMSRV_DAY_idx5 on IZY.F_ADMINSRV_DAY(meas_date);


-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV_DAY (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID,XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);                               

ALTER TABLE IZY.F_APPLSRV_DAY
       ADD CONSTRAINT IZY_FD23
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV_DAY
       ADD CONSTRAINT IZY_FD22
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLSRV_DAY
       ADD CONSTRAINT IZY_FD21
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLSRV_DAY
       ADD CONSTRAINT IZY_FD20
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APPSRV_DAY_idx1 on IZY.F_APPLSRV_DAY(ApplSrv_Comp_ID);
create index IZY.F_APPSRV_DAY_idx2 on IZY.F_APPLSRV_DAY(AdminSrv_Comp_ID);
create index IZY.F_APPSRV_DAY_idx3 on IZY.F_APPLSRV_DAY(XQ_AdminSrv_dttm);
create index IZY.F_APPSRV_DAY_idx4 on IZY.F_APPLSRV_DAY(host_id);
create index IZY.F_APPSRV_DAY_idx5 on IZY.F_APPLSRV_DAY(metric_id);
create index IZY.F_APPSRV_DAY_idx6 on IZY.F_APPLSRV_DAY(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP_DAY (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_APPLCMP_DAY
       ADD CONSTRAINT IZY_FD34
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP_DAY
       ADD CONSTRAINT IZY_FD33
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP_DAY
       ADD CONSTRAINT IZY_FD32
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLCMP_DAY
       ADD CONSTRAINT IZY_FD31
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;


ALTER TABLE IZY.F_APPLCMP_DAY
       ADD CONSTRAINT IZY_FD30
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APPCMP_DAY_idx1 on IZY.F_APPLCMP_DAY(ApplCmp_Comp_ID);
create index IZY.F_APPCMP_DAY_idx2 on IZY.F_APPLCMP_DAY(ApplSrv_Comp_ID);
create index IZY.F_APPCMP_DAY_idx3 on IZY.F_APPLCMP_DAY(AdminSrv_Comp_ID);
create index IZY.F_APPCMP_DAY_idx4 on IZY.F_APPLCMP_DAY(XQ_AdminSrv_dttm);
create index IZY.F_APPCMP_DAY_idx5 on IZY.F_APPLCMP_DAY(host_id);
create index IZY.F_APPCMP_DAY_idx6 on IZY.F_APPLCMP_DAY(metric_id);
create index IZY.F_APPCMP_DAY_idx7 on IZY.F_APPLCMP_DAY(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_SUBCMP_DAY (
  SubCmp_Comp_ID    integer not null,
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_SUBCMP_DAY
       ADD CONSTRAINT IZY_FD45
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP_DAY
       ADD CONSTRAINT IZY_FD44
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP_DAY
       ADD CONSTRAINT IZY_FD43
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP_DAY
       ADD CONSTRAINT IZY_FD42
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_SUBCMP_DAY
       ADD CONSTRAINT IZY_FD41
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;


ALTER TABLE IZY.F_SUBCMP_DAY
       ADD CONSTRAINT IZY_FD40
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SUBCMP_DAY_idx1 on IZY.F_SUBCMP_DAY(SubCmp_Comp_ID);
create index IZY.F_SUBCMP_DAY_idx2 on IZY.F_SUBCMP_DAY(ApplCmp_Comp_ID);
create index IZY.F_SUBCMP_DAY_idx3 on IZY.F_SUBCMP_DAY(ApplSrv_Comp_ID);
create index IZY.F_SUBCMP_DAY_idx4 on IZY.F_SUBCMP_DAY(AdminSrv_Comp_ID);
create index IZY.F_SUBCMP_DAY_idx5 on IZY.F_SUBCMP_DAY(XQ_AdminSrv_dttm);
create index IZY.F_SUBCMP_DAY_idx6 on IZY.F_SUBCMP_DAY(host_id);
create index IZY.F_SUBCMP_DAY_idx7 on IZY.F_SUBCMP_DAY(metric_id);
create index IZY.F_SUBCMP_DAY_idx8 on IZY.F_SUBCMP_DAY(meas_date);


--------------------
--- Fact WEEK level
--------------------

create table IZY.F_ADMINSRV_WEEK (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
   total_value double,
	sample_count integer,
	primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);                                 

ALTER TABLE IZY.F_ADMINSRV_WEEK
       ADD CONSTRAINT IZY_FW12
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_ADMINSRV_WEEK
       ADD CONSTRAINT IZY_FW11
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_ADMINSRV_WEEK
       ADD CONSTRAINT IZY_FW10
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_ADMSRV_WEEK_idx1 on IZY.F_ADMINSRV_WEEK(AdminSrv_Comp_ID);
create index IZY.F_ADMSRV_WEEK_idx2 on IZY.F_ADMINSRV_WEEK(XQ_AdminSrv_dttm);
create index IZY.F_ADMSRV_WEEK_idx3 on IZY.F_ADMINSRV_WEEK(host_id);
create index IZY.F_ADMSRV_WEEK_idx4 on IZY.F_ADMINSRV_WEEK(metric_id);
create index IZY.F_ADMSRV_WEEK_idx5 on IZY.F_ADMINSRV_WEEK(meas_date);


-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV_WEEK (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID,XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);                               

ALTER TABLE IZY.F_APPLSRV_WEEK
       ADD CONSTRAINT IZY_FW23
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV_WEEK
       ADD CONSTRAINT IZY_FW22
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLSRV_WEEK
       ADD CONSTRAINT IZY_FW21
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLSRV_WEEK
       ADD CONSTRAINT IZY_FW20
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APPSRV_WEEK_idx1 on IZY.F_APPLSRV_WEEK(ApplSrv_Comp_ID);
create index IZY.F_APPSRV_WEEK_idx2 on IZY.F_APPLSRV_WEEK(AdminSrv_Comp_ID);
create index IZY.F_APPSRV_WEEK_idx3 on IZY.F_APPLSRV_WEEK(XQ_AdminSrv_dttm);
create index IZY.F_APPSRV_WEEK_idx4 on IZY.F_APPLSRV_WEEK(host_id);
create index IZY.F_APPSRV_WEEK_idx5 on IZY.F_APPLSRV_WEEK(metric_id);
create index IZY.F_APPSRV_WEEK_idx6 on IZY.F_APPLSRV_WEEK(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP_WEEK(                                      
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_APPLCMP_WEEK
       ADD CONSTRAINT IZY_FW34
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP_WEEK
       ADD CONSTRAINT IZY_FW33
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP_WEEK
       ADD CONSTRAINT IZY_FW32
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLCMP_WEEK
       ADD CONSTRAINT IZY_FW31
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLCMP_WEEK
       ADD CONSTRAINT IZY_FW30
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APPCMP_WEEK_idx1 on IZY.F_APPLCMP_WEEK(ApplCmp_Comp_ID);
create index IZY.F_APPCMP_WEEK_idx2 on IZY.F_APPLCMP_WEEK(ApplSrv_Comp_ID);
create index IZY.F_APPCMP_WEEK_idx3 on IZY.F_APPLCMP_WEEK(AdminSrv_Comp_ID);
create index IZY.F_APPCMP_WEEK_idx4 on IZY.F_APPLCMP_WEEK(XQ_AdminSrv_dttm);
create index IZY.F_APPCMP_WEEK_idx5 on IZY.F_APPLCMP_WEEK(host_id);
create index IZY.F_APPCMP_WEEK_idx6 on IZY.F_APPLCMP_WEEK(metric_id);
create index IZY.F_APPCMP_WEEK_idx7 on IZY.F_APPLCMP_WEEK(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 

create table IZY.F_SUBCMP_WEEK(                                  
  SubCmp_Comp_ID    integer not null,
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_SUBCMP_WEEK
       ADD CONSTRAINT IZY_FW45
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP_WEEK
       ADD CONSTRAINT IZY_FW44
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP_WEEK
       ADD CONSTRAINT IZY_FW43
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP_WEEK
       ADD CONSTRAINT IZY_FW42
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_SUBCMP_WEEK
       ADD CONSTRAINT IZY_FW41
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_SUBCMP_WEEK
       ADD CONSTRAINT IZY_FW10
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SUBCMP_WEEK_idx1 on IZY.F_SUBCMP_WEEK(SubCmp_Comp_ID);
create index IZY.F_SUBCMP_WEEK_idx2 on IZY.F_SUBCMP_WEEK(ApplCmp_Comp_ID);
create index IZY.F_SUBCMP_WEEK_idx3 on IZY.F_SUBCMP_WEEK(ApplSrv_Comp_ID);
create index IZY.F_SUBCMP_WEEK_idx4 on IZY.F_SUBCMP_WEEK(AdminSrv_Comp_ID);
create index IZY.F_SUBCMP_WEEK_idx5 on IZY.F_SUBCMP_WEEK(XQ_AdminSrv_dttm);
create index IZY.F_SUBCMP_WEEK_idx6 on IZY.F_SUBCMP_WEEK(host_id);
create index IZY.F_SUBCMP_WEEK_idx7 on IZY.F_SUBCMP_WEEK(metric_id);
create index IZY.F_SUBCMP_WEEK_idx8 on IZY.F_SUBCMP_WEEK(meas_date);



--------------------
-- FACT MONTH table
--------------------

create table IZY.F_ADMINSRV_MONTH (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
   total_value double,
	sample_count integer,
	primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);                                 

ALTER TABLE IZY.F_ADMINSRV_MONTH
       ADD CONSTRAINT IZY_FM12
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_ADMINSRV_MONTH
       ADD CONSTRAINT IZY_FM11
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_ADMINSRV_MONTH
       ADD CONSTRAINT IZY_FM10
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_AMSRV_MONTH_idx1 on IZY.F_ADMINSRV_MONTH(AdminSrv_Comp_ID);
create index IZY.F_AMSRV_MONTH_idx2 on IZY.F_ADMINSRV_MONTH(XQ_AdminSrv_dttm);
create index IZY.F_AMSRV_MONTH_idx3 on IZY.F_ADMINSRV_MONTH(host_id);
create index IZY.F_AMSRV_MONTH_idx4 on IZY.F_ADMINSRV_MONTH(metric_id);
create index IZY.F_AMSRV_MONTH_idx5 on IZY.F_ADMINSRV_MONTH(meas_date);


-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV_MONTH (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID,XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);                               

ALTER TABLE IZY.F_APPLSRV_MONTH
       ADD CONSTRAINT IZY_FM23
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV_MONTH
       ADD CONSTRAINT IZY_FM22
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLSRV_MONTH
       ADD CONSTRAINT IZY_FM21
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLSRV_MONTH
       ADD CONSTRAINT IZY_FM20
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APSRV_MONTH_idx1 on IZY.F_APPLSRV_MONTH(ApplSrv_Comp_ID);
create index IZY.F_APSRV_MONTH_idx2 on IZY.F_APPLSRV_MONTH(AdminSrv_Comp_ID);
create index IZY.F_APSRV_MONTH_idx3 on IZY.F_APPLSRV_MONTH(XQ_AdminSrv_dttm);
create index IZY.F_APSRV_MONTH_idx4 on IZY.F_APPLSRV_MONTH(host_id);
create index IZY.F_APSRV_MONTH_idx5 on IZY.F_APPLSRV_MONTH(metric_id);
create index IZY.F_APSRV_MONTH_idx6 on IZY.F_APPLSRV_MONTH(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP_MONTH(                                      
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_APPLCMP_MONTH
       ADD CONSTRAINT IZY_FM34
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP_MONTH
       ADD CONSTRAINT IZY_FM33
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP_MONTH
       ADD CONSTRAINT IZY_FM32
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_APPLCMP_MONTH
       ADD CONSTRAINT IZY_FM31
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_APPLCMP_MONTH
       ADD CONSTRAINT IZY_FM30
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APCMP_MONTH_idx1 on IZY.F_APPLCMP_MONTH(ApplCmp_Comp_ID);
create index IZY.F_APCMP_MONTH_idx2 on IZY.F_APPLCMP_MONTH(ApplSrv_Comp_ID);
create index IZY.F_APCMP_MONTH_idx3 on IZY.F_APPLCMP_MONTH(AdminSrv_Comp_ID);
create index IZY.F_APCMP_MONTH_idx4 on IZY.F_APPLCMP_MONTH(XQ_AdminSrv_dttm);
create index IZY.F_APCMP_MONTH_idx5 on IZY.F_APPLCMP_MONTH(host_id);
create index IZY.F_APCMP_MONTH_idx6 on IZY.F_APPLCMP_MONTH(metric_id);
create index IZY.F_APCMP_MONTH_idx7 on IZY.F_APPLCMP_MONTH(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 

create table IZY.F_SUBCMP_MONTH(                                  
  SubCmp_Comp_ID    integer not null,
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_SUBCMP_MONTH
       ADD CONSTRAINT IZY_FM45
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP_MONTH
       ADD CONSTRAINT IZY_FM44
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP_MONTH
       ADD CONSTRAINT IZY_FM43
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP_MONTH
       ADD CONSTRAINT IZY_FM42
              FOREIGN KEY (AdminSrv_Comp_ID,XQ_AdminSrv_dttm)
                             REFERENCES IZY.D_WAS_ADMINSRV;

ALTER TABLE IZY.F_SUBCMP_MONTH
       ADD CONSTRAINT IZY_FM41
              FOREIGN KEY (host_id)
                             REFERENCES IZY.D_WAS_HOST;

ALTER TABLE IZY.F_SUBCMP_MONTH
       ADD CONSTRAINT IZY_FM40
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SBCMP_MONTH_idx1 on IZY.F_SUBCMP_MONTH(SubCmp_Comp_ID);
create index IZY.F_SBCMP_MONTH_idx2 on IZY.F_SUBCMP_MONTH(ApplCmp_Comp_ID);
create index IZY.F_SBCMP_MONTH_idx3 on IZY.F_SUBCMP_MONTH(ApplSrv_Comp_ID);
create index IZY.F_SBCMP_MONTH_idx4 on IZY.F_SUBCMP_MONTH(AdminSrv_Comp_ID);
create index IZY.F_SBCMP_MONTH_idx5 on IZY.F_SUBCMP_MONTH(XQ_AdminSrv_dttm);
create index IZY.F_SBCMP_MONTH_idx6 on IZY.F_SUBCMP_MONTH(host_id);
create index IZY.F_SBCMP_MONTH_idx7 on IZY.F_SUBCMP_MONTH(metric_id);
create index IZY.F_SBCMP_MONTH_idx8 on IZY.F_SUBCMP_MONTH(meas_date);



-----------------------------------------------------------------------
-- Create prune mart control table 
-----------------------------------------------------------------------

-- Control table for pruning obsolete data from all fact tables 
-- PMartC_Duration is a field in the format yyymmdd.  For example,
--    300 means 3 months
--  10101 means 1 year 1 month 1 day.
CREATE TABLE IZY.PRUNE_MART_CONTROL (
        Table_Name         VARCHAR(120) NOT NULL,
        PMartC_Duration    DECIMAL(8,0) NOT NULL
);      


-- logging table for pruned records.   
-- Even though pruning has been run, no entries are
-- made in this table if no records have been pruned.
CREATE TABLE IZY.PRUNE_MART_LOG ( 
        PMart_Run_DtTm     timestamp  not null, 
        Table_Name         Varchar(30),   
        PMartC_Duration    DECIMAL(8,0) NOT NULL,    
        Number_Pruned      Decimal(8,0) Not Null
);

