-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
--
-- (C) COPYRIGHT IBM CORP. 2002. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: %W%
-- 
-- Revision: %I%
-- 
-- Date: %G% %U%
-- 
-- Description: IBM Tivoli Monitoring for WebSphere file for inserting 
--              static data into the TWH_Mart database tables for pruning purposes.
-- 
--  ==========================================================================
-- 
-----------------------------------------------------------------------
-- Insert data into control table for pruning obsolete data from all 
-- Monitoring for WebSphere Application Server fact tables.
-- A date duration is decimal(8,0) and has the format yyyymmdd.
-----------------------------------------------------------------------

-- create temporary table for prune mart control
DECLARE global temporary TABLE Prune_Mart_Control(
       Table_Name           VARCHAR(120) NOT NULL,
       PMartC_Duration      DECIMAL(8,0) NOT NULL
) 
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;

INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_ADMINSRV_HOUR', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_ADMINSRV_DAY', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_ADMINSRV_WEEK', 00010000);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_ADMINSRV_MONTH', 00010000);

INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLSRV_HOUR', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLSRV_DAY', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLSRV_WEEK', 00010000);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLSRV_MONTH', 00010000);

INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLCMP_HOUR', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLCMP_DAY', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLCMP_WEEK', 00010000);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_APPLCMP_MONTH', 00010000);


INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_SUBCMP_HOUR', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_SUBCMP_DAY', 00000300);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_SUBCMP_WEEK', 00010000);
INSERT INTO session.Prune_Mart_Control VALUES ('IZY.F_SUBCMP_MONTH', 00010000);

INSERT INTO IZY.Prune_Mart_Control
SELECT 
   s.Table_Name AS Table_Name,
   s.PMartC_Duration AS PMartC_Duration
FROM 
   session.Prune_Mart_Control s
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  IZY.Prune_Mart_Control t
  WHERE
  t.Table_Name = s.Table_Name 
);

-----------------------------------------------------------------------
-- Drop temporary session tables 
-----------------------------------------------------------------------

-- drop temporary table for prune mart control
DROP TABLE session.Prune_Mart_Control;
